aboutsummaryrefslogtreecommitdiffstats
path: root/src/construct/mod.rs
diff options
context:
space:
mode:
authorLibravatar Titus Wormer <tituswormer@gmail.com>2022-08-26 13:29:10 +0200
committerLibravatar Titus Wormer <tituswormer@gmail.com>2022-08-26 13:29:40 +0200
commit670f1d82e01ea2394b21d7d1857f41bdc67b3fce (patch)
treed38fd96745b443dc5ece52c771fa5e39653937c4 /src/construct/mod.rs
parentf41688c067be261279804b8ab3e04cd5d67f492f (diff)
downloadmarkdown-rs-670f1d82e01ea2394b21d7d1857f41bdc67b3fce.tar.gz
markdown-rs-670f1d82e01ea2394b21d7d1857f41bdc67b3fce.tar.bz2
markdown-rs-670f1d82e01ea2394b21d7d1857f41bdc67b3fce.zip
Add support for math (flow)
Diffstat (limited to 'src/construct/mod.rs')
-rw-r--r--src/construct/mod.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/construct/mod.rs b/src/construct/mod.rs
index a0065fa..9add015 100644
--- a/src/construct/mod.rs
+++ b/src/construct/mod.rs
@@ -25,7 +25,7 @@
//! thematic break.
//! These things are called constructs here.
//! Sometimes, there are several constructs that result in an equivalent thing.
//! For example, [code (fenced)][code_fenced] and
//! [code (indented)][code_indented] are considered different constructs.
//!
//! The following constructs are found in markdown (CommonMark):
@@ -36,7 +36,6 @@
//! * [block quote][block_quote]
//! * [character escape][character_escape]
//! * [character reference][character_reference]
-//! * [code (fenced)][code_fenced]
//! * [code (indented)][code_indented]
//! * [code (text)][raw_text]
//! * [definition][]
@@ -50,6 +49,7 @@
//! * [label start (link)][label_start_link]
//! * [list item][list_item]
//! * [paragraph][]
+//! * [raw (flow)][raw_flow] (code (fenced), math (flow))
//! * [thematic break][thematic_break]
//!
//! > 👉 **Note**: for performance reasons, hard break (trailing) is formed by
@@ -143,7 +143,6 @@ pub mod blank_line;
pub mod block_quote;
pub mod character_escape;
pub mod character_reference;
-pub mod code_fenced;
pub mod code_indented;
pub mod definition;
pub mod document;
@@ -172,6 +171,7 @@ pub mod partial_space_or_tab;
pub mod partial_space_or_tab_eol;
pub mod partial_title;
pub mod partial_whitespace;
+pub mod raw_flow;
pub mod raw_text;
pub mod string;
pub mod text;
@@ -25,7 +25,7 @@
//! These things are called constructs here.
//! Sometimes, there are several constructs that result in an equivalent thing.
-//! For example, [code (fenced)][code_fenced] and
+//! For example, [code (fenced)][raw_flow] and
//! [code (indented)][code_indented] are considered different constructs.
//!